@@ -7,10 +7,10 @@ use Carp ();
 use FFI::Temp;
 use File::Basename ();
 use FFI::Build::Platform;
-use overload '""' => sub { $_[0]->path };
+use overload '""' => sub { $_[0]->path }, bool => sub { 1 }, fallback => 1;
 
 # ABSTRACT: Base class for File::Build files
-our $VERSION = '0.95_09'; # TRIAL VERSION
+our $VERSION = '0.95_10'; # TRIAL VERSION
 
 
 sub new
@@ -158,7 +158,7 @@ FFI::Build::File::Base - Base class for File::Build files
 
 =head1 VERSION
 
-version 0.95_09
+version 0.95_10
 
 =head1 SYNOPSIS
 
