@@ -12,7 +12,7 @@ use File::Spec;
 use FFI::Platypus::ShareConfig;
 
 # ABSTRACT: Platform specific configuration.
-our $VERSION = '0.95_09'; # TRIAL VERSION
+our $VERSION = '0.95_10'; # TRIAL VERSION
 
 
 sub new
@@ -71,7 +71,7 @@ sub library_suffix
   {
     push @suffix, '.' . $self->{config}->{dlext};
   }
-  wantarray ? @suffix : $suffix[0];
+  wantarray ? @suffix : $suffix[0];  ## no critic (Freenode::Wantarray)
 }
 
 
@@ -397,7 +397,7 @@ FFI::Build::Platform - Platform specific configuration.
 
 =head1 VERSION
 
-version 0.95_09
+version 0.95_10
 
 =head1 SYNOPSIS
 
