@@ -8,7 +8,7 @@ use FFI::Platypus::Function;
 use FFI::Platypus::Type;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.95_09'; # TRIAL VERSION
+our $VERSION = '0.95_10'; # TRIAL VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -305,8 +305,6 @@ sub _function_meta
 }
 
 
-#my $inner_counter=0;
-
 sub attach
 {
   my $wrapper;
@@ -315,7 +313,8 @@ sub attach
   my $self = shift;
   my $name = shift;
   my $args = shift;
-  my $varargs = shift if defined $_[0] && ref($_[0]) eq 'ARRAY';
+  my $varargs;
+  $varargs = shift if defined $_[0] && ref($_[0]) eq 'ARRAY';
   my $ret = shift;
   my $proto = shift;
 
@@ -504,7 +503,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.95_09
+version 0.95_10
 
 =head1 SYNOPSIS
 
