@@ -8,10 +8,10 @@ use Carp qw( croak );
 use overload '&{}' => sub {
   my $self = shift;
   sub { $self->{code}->(@_) };
-};
+}, bool => sub { 1 }, fallback => 1;
 
 # ABSTRACT: Platypus closure object
-our $VERSION = '0.95_09'; # TRIAL VERSION
+our $VERSION = '0.95_10'; # TRIAL VERSION
 
 
 sub new
@@ -66,7 +66,7 @@ sub unstick
 
 package FFI::Platypus::ClosureData;
 
-our $VERSION = '0.95_09'; # TRIAL VERSION
+our $VERSION = '0.95_10'; # TRIAL VERSION
 
 1;
 
@@ -82,7 +82,7 @@ FFI::Platypus::Closure - Platypus closure object
 
 =head1 VERSION
 
-version 0.95_09
+version 0.95_10
 
 =head1 SYNOPSIS
 
