@@ -5,18 +5,16 @@ use warnings;
 use FFI::Platypus;
 
 # ABSTRACT: An FFI function object
-our $VERSION = '0.95_09'; # TRIAL VERSION
+our $VERSION = '0.95_10'; # TRIAL VERSION
 
 
 use overload '&{}' => sub {
   my $ffi = shift;
   sub { $ffi->call(@_) };
-};
-
-use overload 'bool' => sub {
+}, 'bool' => sub {
   my $ffi = shift;
   return $ffi;
-};
+}, fallback => 1;
 
 package FFI::Platypus::Function::Function;
 
@@ -128,7 +126,7 @@ FFI::Platypus::Function - An FFI function object
 
 =head1 VERSION
 
-version 0.95_09
+version 0.95_10
 
 =head1 SYNOPSIS
 
